package DBIx::Class::EscapeSearch;
use strict;
use warnings;
use base qw/DBIx::Class/;

our $VERSION = '0.01';

__PACKAGE__->load_components(qw/ResultSetManager/);

sub escape_search : ResultSet {
    my $class = shift;
    my $attrs = (@_ > 1 && ref $_[$#_] eq 'HASH' ? pop(@_) : {});
    my $query = ref $_[0] eq 'HASH' ? { %{shift()} }: {@_};
    $query->{$_} =~ s/'/''/g  for keys %$query;
    use Data::Dumper;
    warn Dumper($query);
    return $class->search($query, { %$attrs });
}

1;

__END__

=head1 NAME

DBIx::Class::EscapeSearch - force escape single quote for search method

=head1 SYNOPSIS

    package DBIC::User;
    use base qw/DBIx::Class/;
    __PACKAGE__->load_components(qw/EscapeSearch PK::Auto::SQLite Core/);

and your script

    my $it = $schema->resultset('User')->escape_search({name => {'like' ,$name}});

=head1 DESCRIPTION

DBIx::Class::EscapeSearch is Extension to DBIx::Class.
DBIx::Class::EscapeSearch is easy escape single quote.

=head1 DEPENDENCIES

L<DBIx::Class>

L<DBIx::Class::ResultSetManager>

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Atsushi Kobayashi (E<lt>nekokak@cpan.orgE<gt>)
Patches are welcome.

=head1 SEE ALSO

L<DBIx::Class>

L<DBIx::Class::ResultSetManager>

=head1 AUTHOR

Atsushi Kobayashi, E<lt>nekokak@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 by Atsushi Kobayashi (E<lt>nekokak@cpan.orgE<gt>). All rights reserved.

This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>.

=cut
